@@ -37,7 +37,7 @@ class Exceptions:
 
 class PersonalizeRuntimeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html)
     """
 
@@ -53,21 +53,21 @@ class PersonalizeRuntimeClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#can_paginate)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#generate_presigned_url)
         """
 
@@ -77,14 +77,14 @@ class PersonalizeRuntimeClient(BaseClient):
         campaignArn: str,
         inputList: Sequence[str],
         userId: str,
-        context: Mapping[str, str] = None,
-        filterArn: str = None,
-        filterValues: Mapping[str, str] = None
+        context: Mapping[str, str] = ...,
+        filterArn: str = ...,
+        filterValues: Mapping[str, str] = ...
     ) -> GetPersonalizedRankingResponseTypeDef:
         """
         Re-ranks a list of recommended items for the given user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_personalized_ranking)
         """
 
@@ -92,16 +92,16 @@ class PersonalizeRuntimeClient(BaseClient):
         self,
         *,
         campaignArn: str,
-        itemId: str = None,
-        userId: str = None,
-        numResults: int = None,
-        context: Mapping[str, str] = None,
-        filterArn: str = None,
-        filterValues: Mapping[str, str] = None
+        itemId: str = ...,
+        userId: str = ...,
+        numResults: int = ...,
+        context: Mapping[str, str] = ...,
+        filterArn: str = ...,
+        filterValues: Mapping[str, str] = ...
     ) -> GetRecommendationsResponseTypeDef:
         """
         Returns a list of recommended items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_recommendations)
         """
